@@ -33,9 +33,11 @@ To learn more, check out:   http://pyvows.org
 
 # flake8: noqa
 
+#-------------------------------------------------------------------------------------------------
+
+from preggy import expect
+
 try:
     from pyvows.core import Vows, expect
-    from pyvows.errors import VowsAssertionError
-    from pyvows.assertions import *
 except ImportError:
     pass
